APIHistogram<T extends num> class

APIHistogram is a synchronous Instrument which records a distribution of values.

See the OpenTelemetry specification for more details: https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/metrics/api.md#histogram

Constructors

APIHistogram(String _name, String? _description, String? _unit, bool _enabled, APIMeter _meter, {List<double>? boundaries})
Creates a new APIHistogram instrument.

Properties

boundaries List<double>?
Returns the explicit bucket boundaries, if specified during creation.
no setter
description String?
Returns the description of this Histogram.
no setter
enabled bool
Returns whether this histogram is enabled.
no setter
hashCode int
The hash code for this object.
no setterinherited
isCounter bool
Type identification getters Returns false since this is not a Counter instrument.
no setter
isGauge bool
Returns false since this is not a Gauge instrument.
no setter
isHistogram bool
Returns true since this is a Histogram instrument.
no setter
isUpDownCounter bool
Returns false since this is not an UpDownCounter instrument.
no setter
meter APIMeter
Returns the meter that created this histogram.
no setter
name String
Returns the name of this Histogram.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unit String?
Returns the unit of this Histogram.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
record(T value, [Attributes? attributes]) → void
Records a value in the histogram.
recordWithMap(T value, Map<String, Object> attributeMap) → void
Records a value with the given map of attributes.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited