isCounter property
bool
get
isCounter
Type identification getters Returns false since this is not a Counter instrument.
Implementation
bool get isCounter => false;
Type identification getters Returns false since this is not a Counter instrument.
bool get isCounter => false;