isGauge property
bool
get
isGauge
Returns false since this is not a Gauge instrument.
Implementation
bool get isGauge => false;
Returns false since this is not a Gauge instrument.
bool get isGauge => false;