record method
Records a value in the histogram.
value The value to record.
attributes The set of attributes to associate with this value.
Implementation
void record(T value, [Attributes? attributes]) {
// Base implementation is a no-op
}
Records a value in the histogram.
value The value to record.
attributes The set of attributes to associate with this value.
void record(T value, [Attributes? attributes]) {
// Base implementation is a no-op
}