isHistogram property
bool
get
isHistogram
Returns false since this is not a Histogram instrument.
Implementation
bool get isHistogram => false;
Returns false since this is not a Histogram instrument.
bool get isHistogram => false;