Android enum
android.* attribute keys from the OpenTelemetry
semantic-conventions attribute registry.
- Inheritance
- Implemented types
- Available extensions
Values
- androidAppState → const Android
-
This attribute represents the state of the application.
Examples:
createdStability: development
const Android('android.app.state') - androidOsApiLevel → const Android
-
Uniquely identifies the framework API revision offered by a version (
os.version) of the android operating system. More information can be found in the Android API levels documentation .Examples:
33, 32Stability: development
const Android('android.os.api_level') - androidState → const Android
-
Deprecated. Use
android.app.stateattribute instead.Stability: development
const Android('android.state')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- key → String
-
The attribute key string as defined in the OpenTelemetry specification.
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMapEntry(
Object value) → MapEntry< String, Object> -
Available on OTelSemantic, provided by the OTelSemanticExtension extension
Converts this semantic attribute and its value to aMapEntry. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited