AzEvent enum

az event names from the OpenTelemetry semantic conventions.

Inheritance
Implemented types
Available extensions

Values

azResourceLog → const AzEvent

Deprecated. Use azure.resource.log instead.

Stability: development

const AzEvent('az.resource.log')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String
The on-wire event name (e.g. exception, feature_flag.evaluation).
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AzEvent>
A constant List of the values in this enum, in order of their declaration.