IosAppState enum

Values for ios.app.state.

Stability: development

Inheritance
Implemented types
Available extensions

Values

active → const IosAppState

The app has become active. Associated with UIKit notification applicationDidBecomeActive.

Stability: development

const IosAppState('active')
inactive → const IosAppState

The app is now inactive. Associated with UIKit notification applicationWillResignActive.

Stability: development

const IosAppState('inactive')
background → const IosAppState

The app is now in the background. This value is associated with UIKit notification applicationDidEnterBackground.

Stability: development

const IosAppState('background')
foreground → const IosAppState

The app is now in the foreground. This value is associated with UIKit notification applicationWillEnterForeground.

Stability: development

const IosAppState('foreground')
terminate → const IosAppState

The app is about to terminate. Associated with UIKit notification applicationWillTerminate.

Stability: development

const IosAppState('terminate')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The on-wire attribute value string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IosAppState>
A constant List of the values in this enum, in order of their declaration.