attributes static method
Creates an Attributes collection from a list of Attributes.
Implementation
static Attributes attributes([List<Attribute>? entries]) {
_getAndCacheOtelFactory();
return OTelFactory.otelFactory!.attributes(entries);
}
Creates an Attributes collection from a list of Attributes.
static Attributes attributes([List<Attribute>? entries]) {
_getAndCacheOtelFactory();
return OTelFactory.otelFactory!.attributes(entries);
}