attributesFromList static method

Attributes attributesFromList(
  1. List<Attribute<Object>> attributeList
)

Creates attributes from a list of individual attribute objects.

This converts a list of Attribute objects into a single Attributes collection.

@param attributeList The list of attributes to include in the collection @return A new Attributes instance containing all the provided attributes

Implementation

static Attributes attributesFromList(List<Attribute> attributeList) {
  _getAndCacheOtelFactory();
  return OTelFactory.otelFactory!.attributesFromList(attributeList);
}