OTelSemantic class abstract

Base interface for OpenTelemetry semantic-convention attribute-key enums. Every generated attribute-key enum implements this; consumers can also implement it on their own app-specific enums to mix into attributesFromSemanticMap.

Implementers
Available extensions

Constructors

OTelSemantic(String key)
Base const constructor.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
The attribute key string as defined in the OpenTelemetry specification.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMapEntry(Object value) MapEntry<String, Object>

Available on OTelSemantic, provided by the OTelSemanticExtension extension

Converts this semantic attribute and its value to a MapEntry.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited