Oracle enum

oracle.* attribute keys from the OpenTelemetry semantic-conventions attribute registry.

Inheritance
Implemented types
Available extensions

Values

oracleDbDomain → const Oracle

The database domain associated with the connection.

Examples: example.com, corp.internal, prod.db.local

Stability: release_candidate

const Oracle('oracle.db.domain')
oracleDbInstanceName → const Oracle

The instance name associated with the connection in an Oracle Real Application Clusters environment.

Examples: ORCL1, ORCL2, ORCL3

Stability: release_candidate

const Oracle('oracle.db.instance.name')
oracleDbName → const Oracle

The database name associated with the connection.

Examples: ORCL1, FREE

Stability: release_candidate

const Oracle('oracle.db.name')
oracleDbPdb → const Oracle

The pluggable database (PDB) name associated with the connection.

Examples: PDB1, FREEPDB

Stability: release_candidate

const Oracle('oracle.db.pdb')
oracleDbService → const Oracle

The service name currently associated with the database connection.

Examples: order-processing-service, db_low.adb.oraclecloud.com, db_high.adb.oraclecloud.com

Stability: release_candidate

const Oracle('oracle.db.service')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
key String
The attribute key string as defined in the OpenTelemetry specification.
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMapEntry(Object value) MapEntry<String, Object>

Available on OTelSemantic, provided by the OTelSemanticExtension extension

Converts this semantic attribute and its value to a MapEntry.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Oracle>
A constant List of the values in this enum, in order of their declaration.