attributes property
Additional attributes providing context about this event.
These attributes can include any relevant details about the event not captured in the name.
Implementation
final Attributes? attributes;
Additional attributes providing context about this event.
These attributes can include any relevant details about the event not captured in the name.
final Attributes? attributes;