SystemCpuState enum

Values for system.cpu.state.

Stability: development

Inheritance
Implemented types
Available extensions
Annotations

Values

user → const SystemCpuState

Stability: development

const SystemCpuState('user')
system → const SystemCpuState

Stability: development

const SystemCpuState('system')
nice → const SystemCpuState

Stability: development

const SystemCpuState('nice')
idle → const SystemCpuState

Stability: development

const SystemCpuState('idle')
iowait → const SystemCpuState

Stability: development

const SystemCpuState('iowait')
interrupt → const SystemCpuState

Stability: development

const SystemCpuState('interrupt')
steal → const SystemCpuState

Stability: development

const SystemCpuState('steal')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The on-wire attribute value string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SystemCpuState>
A constant List of the values in this enum, in order of their declaration.