TestSuiteRunStatus enum

Values for test.suite.run.status.

Stability: development

Inheritance
Implemented types
Available extensions

Values

success → const TestSuiteRunStatus

success

Stability: development

const TestSuiteRunStatus('success')
failure → const TestSuiteRunStatus

failure

Stability: development

const TestSuiteRunStatus('failure')
skipped → const TestSuiteRunStatus

skipped

Stability: development

const TestSuiteRunStatus('skipped')
aborted → const TestSuiteRunStatus

aborted

Stability: development

const TestSuiteRunStatus('aborted')
timedOut → const TestSuiteRunStatus

timed_out

Stability: development

const TestSuiteRunStatus('timed_out')
inProgress → const TestSuiteRunStatus

in_progress

Stability: development

const TestSuiteRunStatus('in_progress')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The on-wire attribute value string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TestSuiteRunStatus>
A constant List of the values in this enum, in order of their declaration.