entries property

Map<String, String> get entries

Returns an unmodifiable view of all key-value entries in this trace state.

The returned map cannot be modified, so changes to trace state must be made through the put() and remove() methods.

Implementation

Map<String, String> get entries => Map.unmodifiable(_entries);