dartastic_opentelemetry_api library
OpenTelemetry API for Dart
This library provides the OpenTelemetry API implementation for Dart, following the OpenTelemetry specification. It includes support for tracing, metrics, baggage, and context propagation.
For more information, see the OpenTelemetry specification at https://opentelemetry.io/docs/specs/otel/
Classes
-
APICallbackRegistration<
T extends num> - A registration for an observable callback.
-
APICounter<
T extends num> - APICounter is a synchronous Instrument which supports non-negative increments.
-
APIGauge<
T extends num> - APIGauge is a synchronous Instrument which reports instantaneous measurements.
-
APIHistogram<
T extends num> - APIHistogram is a synchronous Instrument which records a distribution of values.
- APIInstrument
- The base interface for all metric instruments.
- APILogger
-
Logger is responsible for creating
LogRecordss. The API prefix indicates that it's part of the API and not the SDK and generally should not be used since an API without an SDK is a noop. Use the Logger from the SDK instead. - APILoggerProvider
-
APILoggerProvider is the entry point of the OpenTelemetry logger API.
The API prefix indicates that it's part of the API and not the SDK
and generally should not be used since an API without an SDK is a noop.
Use the LoggerProvider from the SDK instead.
It provides access to APILoggers which are used to log operations.
You cannot create a LoggerProvider directly;
you must use OTelAPI or more likely
OTel, for example to get the default logger: - APIMeter
-
Meter is responsible for creating
Instruments and recording metrics. The API prefix indicates that it's part of the API and not the SDK and generally should not be used since an API without an SDK is a noop. Use the Meter from the SDK instead. - APIMeterProvider
-
APIMeterProvider is the entry point of the OpenTelemetry metrics API.
The API prefix indicates that it's part of the API and not the SDK
and generally should not be used since an API without an SDK is a noop.
Use the MeterProvider from the SDK instead.
It provides access to APIMeters which are used to record metrics.
You cannot create a MeterProvider directly;
you must use OTelAPI or more likely,
OTel, for example to get the default meter provider: -
APIObservableCounter<
T extends num> - APIObservableCounter is an asynchronous Instrument which reports monotonically increasing value(s) when the instrument is being observed.
-
APIObservableGauge<
T extends num> - APIObservableGauge is an asynchronous Instrument which reports non-additive value(s) when the instrument is being observed.
-
APIObservableResult<
T extends num> - Interface for recording observations from observable instruments.
-
APIObservableUpDownCounter<
T extends num> - APIObservableUpDownCounter is an asynchronous Instrument which reports values that increase or decrease when the instrument is being observed.
- APISpan
- Span represents a single operation within a trace. The API prefix indicates that it's part of the API and not the SDK and generally should not be used since an API without an SDK is a noop. Use the TracerProvider from the SDK instead. Spans can be nested to form a trace tree. Each trace contains a root span, which typically describes the end-to-end latency, and zero or more sub-spans for its sub-operations. Any span that is created MUST also be ended. This is the responsibility of the user. API implementations MAY leak memory or other resources (including, for example, CPU time for periodic work that iterates all spans) if the user forgot to end the span.
- APITracer
- Tracer is responsible for creating APISpans and propagating context in-process. The API prefix indicates that it's part of the API and not the SDK and generally should not be used since an API without an SDK is a noop. Use the TracerProvider from the SDK instead.
- APITracerProvider
-
APITracerProvider is the entry point of the OpenTelemetry tracing API.
The API prefix indicates that it's part of the API and not the SDK
and generally should not be used since an API without an SDK is a noop.
Use the TracerProvider from the SDK instead.
It provides access to APITracers which are used to trace operations.
You cannot create a TracerProvider directly;
you must use OTelAPI or more likely
OTel, for example to get the default tracer: -
APIUpDownCounter<
T extends num> - APIUpDownCounter is a synchronous Instrument which supports increments and decrements.
-
Attribute<
T extends Object> - Represents a value for an attribute, associated with an attribute key.
- Attributes
- A collection of attributes that are immutable and type-safe. Create with the OTelFactory methods.
- Baggage
- Immutable Baggage that stores entries with unique string keys.
- BaggageEntry
- A single entry within Baggage. Typically just a value plus optional metadata.
- BaggageEntryFactory
- Factory for creating BaggageEntry instances. This is used internally by the OpenTelemetry API implementation.
-
CompositePropagator<
C, V> - A propagator that combines multiple other propagators.
- Context
- Represents the immutable context containing active spans, baggage, and other data.
-
ContextKey<
T> - Key for Context values Each instance is unique, even if created with the same name.
-
ContextPropagator<
C> - A propagator for binary values that can inject into and extract from a carrier.
- HttpHeaderAttribute
- Utility class for creating OpenTelemetry HTTP header attribute keys.
- IdGenerator
- Generates trace and span IDs according to the W3C Trace Context specification.
- InstrumentationScope
- Represents the instrumentation scope information.
- LogRecord
- Required parameter for LogRecord. According to the spec in https://opentelemetry.io/docs/specs/otel/logs/api/#emit-a-logrecord
-
Measurement<
T extends num> - Represents a data point reported via the metrics API.
- NonRecordingSpan
- A non-recording APISpan that carries a SpanContext without recording anything.
-
NoopTextMapPropagator<
C, V> - A TextMapPropagator that propagates nothing.
- OTelAPI
- The OTelAPI is the no-op API implementation of OTel, as required by the specification This class should only be used in the rare case of running without and SDK It is provided to comply with the specifiction requirement that the API can be used without an SDK installed. The initialize method must be called first. Internally it sets the OTelFactory to OTelAPIFactory. The rest of the methods act like factory constructors for OTelAPI classes.
- OTelAPIFactory
- The factory used when no SDK is installed. The OpenTelemetry specification requires the API to work without an SDK installed All construction APIs use the factory, such as builders or 'from' helpers.
- OTelEntity
- Base interface for entity enums.
- OTelEvent
- Base interface for event-name enums.
- OTelFactory
-
The
OTelFactoryis the plugin mechanism for OpenTelemetry SDK's. The OpenTelemetry specifies that the API must work without any SDK installed. The API uses theOTelAPIFactoryas a default. SDKs override this default by registering their own APIFactory - OTelLog
- A simple log service that logs messages and signals to the console. It filters messages based on the current log level. Signals are not filtered based on log level Defaults to noop,
- OTelMetric
- Base interface for metric-name enums.
- OTelSemantic
-
Base interface for OpenTelemetry semantic-convention attribute-key
enums. Every generated attribute-key enum implements this; consumers
can also implement it on their own app-specific enums to mix into
attributesFromSemanticMap. - OTelSemanticIntValue
-
Marker on every int-valued value enum (e.g. the values of
cpython.gc.generation) — exposes the on-wire integer value. - OTelSemanticValue
-
Marker on every string-valued value enum — exposes the on-wire string
value and a
toString()that returns it. Modeled on the same shape as OTelSemantic, but kept separate because these are values, not keys. - SemconvRegistry
- Index of every generated semantic-convention enum, plus the registry version this package was generated from.
- SpanContext
- Immutable representation of a SpanContext. A SpanContext contains the state that must propagate to child Spans and across process boundaries. SpanContext follows the W3C Trace Context specification.
- SpanEvent
- Represents an event that occurred during a span's lifetime.
- SpanId
- A span identifier - an 8-byte array with an ID in a base-16 hex format. Follows W3C Trace Context specification.
- SpanLink
- Represents a link between spans in potentially different traces.
- SystemTimeProvider
- Default TimeProvider backed by DateTime.now.
-
TextMapGetter<
T> - TextMapGetter allows an SDK to read values from a carrier object
-
TextMapPropagator<
C, V> - Interface for propagating context between processes using text maps
-
TextMapSetter<
T> - TextMapSetter allows an SDK to set values on a carrier object
- TimeProvider
- A clock for span start, end, and event timestamps.
- Timestamp
- Utility class for working with OpenTelemetry timestamps.
- TraceFlags
- Trace flags for a SpanContext. These flags are used to control tracing behavior. TraceFlags follows the W3C Trace Context specification.
- TraceId
- A trace identifier - a 16-byte array with an ID in a base-16 hex format. TraceId follows the W3C Trace Context specification.
- TraceState
- Key-value pairs carried along with a span context. TraceState follows the W3C Trace Context specification.
- WebTimeProvider
- Native-target stub for WebTimeProvider.
Enums
- Android
-
android.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - AndroidAppState
-
Values for
android.app.state. - AndroidEntity
-
androidentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - AndroidState
-
Values for
android.state. - App
-
app.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - AppEntity
-
appentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - AppEvent
-
appevent names from the OpenTelemetry semantic conventions. - Artifact
-
artifact.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - Aspnetcore
-
aspnetcore.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - AspnetcoreAuthenticationResult
-
Values for
aspnetcore.authentication.result. - AspnetcoreAuthorizationResult
-
Values for
aspnetcore.authorization.result. - AspnetcoreDiagnosticsExceptionResult
-
Values for
aspnetcore.diagnostics.exception.result. - AspnetcoreIdentityPasswordCheckResult
-
Values for
aspnetcore.identity.password_check_result. - AspnetcoreIdentityResult
-
Values for
aspnetcore.identity.result. - AspnetcoreIdentitySignInResult
-
Values for
aspnetcore.identity.sign_in.result. - AspnetcoreIdentitySignInType
-
Values for
aspnetcore.identity.sign_in.type. - AspnetcoreIdentityTokenPurpose
-
Values for
aspnetcore.identity.token_purpose. - AspnetcoreIdentityTokenVerified
-
Values for
aspnetcore.identity.token_verified. - AspnetcoreIdentityUserUpdateType
-
Values for
aspnetcore.identity.user.update_type. - AspnetcoreMetric
-
aspnetcore.*metric instruments from the OpenTelemetry semantic conventions. - AspnetcoreRateLimitingResult
-
Values for
aspnetcore.rate_limiting.result. - AspnetcoreRoutingMatchStatus
-
Values for
aspnetcore.routing.match_status. - Aws
-
aws.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - AwsEcsLaunchtype
-
Values for
aws.ecs.launchtype. - AwsEntity
-
awsentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - Az
-
az.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - AzEvent
-
azevent names from the OpenTelemetry semantic conventions. - Azure
-
azure.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - AzureCosmosdbConnectionMode
-
Values for
azure.cosmosdb.connection.mode. - AzureCosmosdbConsistencyLevel
-
Values for
azure.cosmosdb.consistency.level. - AzureEvent
-
azureevent names from the OpenTelemetry semantic conventions. - AzureMetric
-
azure.*metric instruments from the OpenTelemetry semantic conventions. - Browser
-
browser.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - BrowserEntity
-
browserentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - BrowserEvent
-
browserevent names from the OpenTelemetry semantic conventions. - Cassandra
-
cassandra.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - CassandraConsistencyLevel
-
Values for
cassandra.consistency.level. - Cicd
-
cicd.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - CicdEntity
-
cicdentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - CicdMetric
-
cicd.*metric instruments from the OpenTelemetry semantic conventions. - CicdPipelineActionName
-
Values for
cicd.pipeline.action.name. - CicdPipelineResult
-
Values for
cicd.pipeline.result. - CicdPipelineRunState
-
Values for
cicd.pipeline.run.state. - CicdPipelineTaskRunResult
-
Values for
cicd.pipeline.task.run.result. - CicdPipelineTaskType
-
Values for
cicd.pipeline.task.type. - CicdWorkerState
-
Values for
cicd.worker.state. - Client
-
client.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - Cloud
-
cloud.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - CloudEntity
-
cloudentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - Cloudevents
-
cloudevents.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - Cloudfoundry
-
cloudfoundry.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - CloudfoundryEntity
-
cloudfoundryentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - CloudPlatform
-
Values for
cloud.platform. - CloudProvider
-
Values for
cloud.provider. - Code
-
code.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - ContainerAttributes
-
container.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - ContainerCpuState
-
Values for
container.cpu.state. - ContainerEntity
-
containerentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - ContainerMetric
-
container.*metric instruments from the OpenTelemetry semantic conventions. - Cpu
-
cpu.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - CpuMetric
-
cpu.*metric instruments from the OpenTelemetry semantic conventions. - CpuMode
-
Values for
cpu.mode. - Cpython
-
cpython.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - CpythonGcGeneration
-
Values for
cpython.gc.generation. - CpythonMetric
-
cpython.*metric instruments from the OpenTelemetry semantic conventions. - Db
-
db.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - DbCassandraConsistencyLevel
-
Values for
db.cassandra.consistency_level. - DbClientConnectionsState
-
Values for
db.client.connections.state. - DbClientConnectionState
-
Values for
db.client.connection.state. - DbCosmosdbConnectionMode
-
Values for
db.cosmosdb.connection_mode. - DbCosmosdbConsistencyLevel
-
Values for
db.cosmosdb.consistency_level. - DbCosmosdbOperationType
-
Values for
db.cosmosdb.operation_type. - DbEvent
-
dbevent names from the OpenTelemetry semantic conventions. - DbMetric
-
db.*metric instruments from the OpenTelemetry semantic conventions. - DbSystem
-
Values for
db.system. - DbSystemName
-
Values for
db.system.name. - Deployment
-
deployment.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - DeploymentEntity
-
deploymententities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - DeploymentEnvironmentName
-
Values for
deployment.environment.name. - DeploymentStatus
-
Values for
deployment.status. - Destination
-
destination.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - Device
-
device.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - DeviceEntity
-
deviceentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - DeviceEvent
-
deviceevent names from the OpenTelemetry semantic conventions. - Disk
-
disk.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - DiskIoDirection
-
Values for
disk.io.direction. - Dns
-
dns.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - DnsMetric
-
dns.*metric instruments from the OpenTelemetry semantic conventions. - Dotnet
-
dotnet.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - DotnetGcHeapGeneration
-
Values for
dotnet.gc.heap.generation. - DotnetMetric
-
dotnet.*metric instruments from the OpenTelemetry semantic conventions. - Elasticsearch
-
elasticsearch.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - Enduser
-
enduser.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - ErrorAttributes
-
error.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - ErrorType
-
Values for
error.type. - EventAttributes
-
event.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - ExceptionAttributes
-
exception.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - ExceptionEvent
-
exceptionevent names from the OpenTelemetry semantic conventions. - Faas
-
faas.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - FaasDocumentOperation
-
Values for
faas.document.operation. - FaasEntity
-
faasentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - FaasEvent
-
faasevent names from the OpenTelemetry semantic conventions. - FaasInvokedProvider
-
Values for
faas.invoked_provider. - FaasMetric
-
faas.*metric instruments from the OpenTelemetry semantic conventions. - FaasTrigger
-
Values for
faas.trigger. - FeatureFlag
-
feature_flag.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - FeatureFlagEvaluationReason
-
Values for
feature_flag.evaluation.reason. - FeatureFlagEvent
-
feature_flagevent names from the OpenTelemetry semantic conventions. - FeatureFlagResultReason
-
Values for
feature_flag.result.reason. - FileAttributes
-
file.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - FileLockType
-
Values for
file.lock.type. - Gcp
-
gcp.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - GcpApphubDestinationServiceCriticalityType
-
Values for
gcp.apphub_destination.service.criticality_type. - GcpApphubDestinationServiceEnvironmentType
-
Values for
gcp.apphub_destination.service.environment_type. - GcpApphubDestinationWorkloadCriticalityType
-
Values for
gcp.apphub_destination.workload.criticality_type. - GcpApphubDestinationWorkloadEnvironmentType
-
Values for
gcp.apphub_destination.workload.environment_type. - GcpApphubServiceCriticalityType
-
Values for
gcp.apphub.service.criticality_type. - GcpApphubServiceEnvironmentType
-
Values for
gcp.apphub.service.environment_type. - GcpApphubWorkloadCriticalityType
-
Values for
gcp.apphub.workload.criticality_type. - GcpApphubWorkloadEnvironmentType
-
Values for
gcp.apphub.workload.environment_type. - GcpEntity
-
gcpentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - GenAi
-
gen_ai.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - GenAiEvent
-
gen_aievent names from the OpenTelemetry semantic conventions. - GenAiMetric
-
gen_ai.*metric instruments from the OpenTelemetry semantic conventions. - GenAiOpenaiRequestResponseFormat
-
Values for
gen_ai.openai.request.response_format. - GenAiOpenaiRequestServiceTier
-
Values for
gen_ai.openai.request.service_tier. - GenAiOperationName
-
Values for
gen_ai.operation.name. - GenAiOutputType
-
Values for
gen_ai.output.type. - GenAiProviderName
-
Values for
gen_ai.provider.name. - GenAiSystem
-
Values for
gen_ai.system. - GenAiTokenType
-
Values for
gen_ai.token.type. - Geo
-
geo.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - GeoContinentCode
-
Values for
geo.continent.code. - Go
-
go.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - GoCpuState
-
Values for
go.cpu.state. - GoMemoryType
-
Values for
go.memory.type. - GoMetric
-
go.*metric instruments from the OpenTelemetry semantic conventions. - Graphql
-
graphql.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - GraphqlOperationType
-
Values for
graphql.operation.type. - Heroku
-
heroku.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - HerokuEntity
-
herokuentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - Host
-
host.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - HostArch
-
Values for
host.arch. - HostEntity
-
hostentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - Http
-
http.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - HttpConnectionState
-
Values for
http.connection.state. - HttpEvent
-
httpevent names from the OpenTelemetry semantic conventions. - HttpFlavor
-
Values for
http.flavor. - HttpMetric
-
http.*metric instruments from the OpenTelemetry semantic conventions. - HttpRequestMethod
-
Values for
http.request.method. - Hw
-
hw.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - HwBatteryState
-
Values for
hw.battery.state. - HwGpuTask
-
Values for
hw.gpu.task. - HwLimitType
-
Values for
hw.limit_type. - HwLogicalDiskState
-
Values for
hw.logical_disk.state. - HwMetric
-
hw.*metric instruments from the OpenTelemetry semantic conventions. - HwPhysicalDiskState
-
Values for
hw.physical_disk.state. - HwState
-
Values for
hw.state. - HwTapeDriveOperationType
-
Values for
hw.tape_drive.operation_type. - HwType
-
Values for
hw.type. - Ios
-
ios.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - IosAppState
-
Values for
ios.app.state. - IosState
-
Values for
ios.state. - Jsonrpc
-
jsonrpc.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - Jvm
-
jvm.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - JvmMemoryType
-
Values for
jvm.memory.type. - JvmMetric
-
jvm.*metric instruments from the OpenTelemetry semantic conventions. - JvmThreadState
-
Values for
jvm.thread.state. - K8s
-
k8s.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - K8sContainerEphemeralStorageFsType
-
Values for
k8s.container.ephemeral_storage.fs_type. - K8sContainerStatusReason
-
Values for
k8s.container.status.reason. - K8sContainerStatusState
-
Values for
k8s.container.status.state. - K8sEntity
-
k8sentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - K8sMetric
-
k8s.*metric instruments from the OpenTelemetry semantic conventions. - K8sNamespacePhase
-
Values for
k8s.namespace.phase. - K8sNodeConditionStatus
-
Values for
k8s.node.condition.status. - K8sNodeConditionType
-
Values for
k8s.node.condition.type. - K8sPersistentvolumeclaimStatusPhase
-
Values for
k8s.persistentvolumeclaim.status.phase. - K8sPersistentvolumeReclaimPolicy
-
Values for
k8s.persistentvolume.reclaim_policy. - K8sPersistentvolumeStatusPhase
-
Values for
k8s.persistentvolume.status.phase. - K8sPodStatusPhase
-
Values for
k8s.pod.status.phase. - K8sPodStatusReason
-
Values for
k8s.pod.status.reason. - K8sServiceEndpointAddressType
-
Values for
k8s.service.endpoint.address_type. - K8sServiceEndpointCondition
-
Values for
k8s.service.endpoint.condition. - K8sServiceType
-
Values for
k8s.service.type. - K8sVolumeType
-
Values for
k8s.volume.type. - KestrelMetric
-
kestrel.*metric instruments from the OpenTelemetry semantic conventions. - Linux
-
linux.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - LinuxMemorySlabState
-
Values for
linux.memory.slab.state. - Log
-
log.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - LogIostream
-
Values for
log.iostream. - LogLevel
- The log levels supported by OTelLog.
- Mainframe
-
mainframe.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - Mcp
-
mcp.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - McpMethodName
-
Values for
mcp.method.name. - McpMetric
-
mcp.*metric instruments from the OpenTelemetry semantic conventions. - Message
-
message.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - MessageType
-
Values for
message.type. - Messaging
-
messaging.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - MessagingEvent
-
messagingevent names from the OpenTelemetry semantic conventions. - MessagingMetric
-
messaging.*metric instruments from the OpenTelemetry semantic conventions. - MessagingOperationType
-
Values for
messaging.operation.type. - MessagingRocketmqConsumptionModel
-
Values for
messaging.rocketmq.consumption_model. - MessagingRocketmqMessageType
-
Values for
messaging.rocketmq.message.type. - MessagingServicebusDispositionStatus
-
Values for
messaging.servicebus.disposition_status. - MessagingSystem
-
Values for
messaging.system. - Net
-
net.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - NetSockFamily
-
Values for
net.sock.family. - NetTransport
-
Values for
net.transport. - Network
-
network.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - NetworkConnectionState
-
Values for
network.connection.state. - NetworkConnectionSubtype
-
Values for
network.connection.subtype. - NetworkConnectionType
-
Values for
network.connection.type. - NetworkIoDirection
-
Values for
network.io.direction. - NetworkTransport
-
Values for
network.transport. - NetworkType
-
Values for
network.type. - Nfs
-
nfs.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - NfsMetric
-
nfs.*metric instruments from the OpenTelemetry semantic conventions. - Nodejs
-
nodejs.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - NodejsEventloopState
-
Values for
nodejs.eventloop.state. - NodejsMetric
-
nodejs.*metric instruments from the OpenTelemetry semantic conventions. - Oci
-
oci.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - OncRpc
-
onc_rpc.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - Openai
-
openai.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - OpenaiApiType
-
Values for
openai.api.type. - OpenaiRequestServiceTier
-
Values for
openai.request.service_tier. - Openshift
-
openshift.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - OpenshiftEntity
-
openshiftentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - OpenshiftMetric
-
openshift.*metric instruments from the OpenTelemetry semantic conventions. - Opentracing
-
opentracing.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - OpentracingRefType
-
Values for
opentracing.ref_type. - Oracle
-
oracle.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - OracleCloud
-
oracle_cloud.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - Os
-
os.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - OsEntity
-
osentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - OsType
-
Values for
os.type. - Otel
-
otel.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - OtelComponentType
-
Values for
otel.component.type. - OtelEntity
-
otelentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - OtelMetric
-
otel.*metric instruments from the OpenTelemetry semantic conventions. - OtelSpanParentOrigin
-
Values for
otel.span.parent.origin. - OtelSpanSamplingResult
-
Values for
otel.span.sampling_result. - OtelStatusCode
-
Values for
otel.status_code. - Other
-
other.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - Peer
-
peer.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - Pool
-
pool.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - Pprof
-
pprof.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - ProcessAttributes
-
process.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - ProcessContextSwitchType
-
Values for
process.context_switch.type. - ProcessCpuState
-
Values for
process.cpu.state. - ProcessEntity
-
processentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - ProcessMetric
-
process.*metric instruments from the OpenTelemetry semantic conventions. - ProcessPagingFaultType
-
Values for
process.paging.fault_type. - ProcessState
-
Values for
process.state. - Profile
-
profile.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - ProfileFrameType
-
Values for
profile.frame.type. - Rpc
-
rpc.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - RpcConnectRpcErrorCode
-
Values for
rpc.connect_rpc.error_code. - RpcEvent
-
rpcevent names from the OpenTelemetry semantic conventions. - RpcGrpcStatusCode
-
Values for
rpc.grpc.status_code. - RpcMessageType
-
Values for
rpc.message.type. - RpcMetric
-
rpc.*metric instruments from the OpenTelemetry semantic conventions. - RpcSystem
-
Values for
rpc.system. - RpcSystemName
-
Values for
rpc.system.name. - SecurityRule
-
security_rule.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - SemanticInstrument
- The four OTel instrument kinds.
- Server
-
server.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - Service
-
service.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - ServiceCriticality
-
Values for
service.criticality. - ServiceEntity
-
serviceentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - Session
-
session.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - SessionEvent
-
sessionevent names from the OpenTelemetry semantic conventions. - Severity
- SeverityLevel
- Signalr
-
signalr.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - SignalrConnectionStatus
-
Values for
signalr.connection.status. - SignalrMetric
-
signalr.*metric instruments from the OpenTelemetry semantic conventions. - SignalrTransport
-
Values for
signalr.transport. - Source
-
source.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - SpanKind
- Type of span. Can be used to specify additional relationships between spans in addition to a parent/child relationship.
- SpanStatusCode
- The set of canonical status codes.
- StateValue
-
Values for
state. - System
-
system.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - SystemCpuState
-
Values for
system.cpu.state. - SystemFilesystemState
-
Values for
system.filesystem.state. - SystemFilesystemType
-
Values for
system.filesystem.type. - SystemMemoryLinuxHugepagesState
-
Values for
system.memory.linux.hugepages.state. - SystemMemoryLinuxSlabState
-
Values for
system.memory.linux.slab.state. - SystemMemoryState
-
Values for
system.memory.state. - SystemMetric
-
system.*metric instruments from the OpenTelemetry semantic conventions. - SystemNetworkState
-
Values for
system.network.state. - SystemPagingDirection
-
Values for
system.paging.direction. - SystemPagingFaultType
-
Values for
system.paging.fault.type. - SystemPagingState
-
Values for
system.paging.state. - SystemPagingType
-
Values for
system.paging.type. - SystemProcessesStatus
-
Values for
system.processes.status. - SystemProcessStatus
-
Values for
system.process.status. - Telemetry
-
telemetry.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - TelemetryEntity
-
telemetryentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - TelemetrySdkLanguage
-
Values for
telemetry.sdk.language. - Test
-
test.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - TestCaseResultStatus
-
Values for
test.case.result.status. - TestSuiteRunStatus
-
Values for
test.suite.run.status. - Thread
-
thread.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - Tls
-
tls.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - TlsProtocolName
-
Values for
tls.protocol.name. - Url
-
url.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - User
-
user.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - UserAgent
-
user_agent.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - UserAgentSyntheticType
-
Values for
user_agent.synthetic.type. - V8js
-
v8js.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - V8jsGcType
-
Values for
v8js.gc.type. - V8jsHeapSpaceName
-
Values for
v8js.heap.space.name. - V8jsMetric
-
v8js.*metric instruments from the OpenTelemetry semantic conventions. - V8jsResourceType
-
Values for
v8js.resource.type. - Vcs
-
vcs.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - VcsChangeState
-
Values for
vcs.change.state. - VcsEntity
-
vcsentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - VcsLineChangeType
-
Values for
vcs.line_change.type. - VcsMetric
-
vcs.*metric instruments from the OpenTelemetry semantic conventions. - VcsProviderName
-
Values for
vcs.provider.name. - VcsRefBaseType
-
Values for
vcs.ref.base.type. - VcsRefHeadType
-
Values for
vcs.ref.head.type. - VcsRefType
-
Values for
vcs.ref.type. - VcsRepositoryRefType
-
Values for
vcs.repository.ref.type. - VcsRevisionDeltaDirection
-
Values for
vcs.revision_delta.direction. - Webengine
-
webengine.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - WebengineEntity
-
webengineentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it. - Zos
-
zos.*attribute keys from the OpenTelemetry semantic-conventions attribute registry. - ZosEntity
-
zosentities from the OpenTelemetry semantic conventions. Each member carries the entity type string plus the attribute keys that identify and describe it.
Extensions
-
AttributesExtension
on Map<
String, Object> - Extension to create Attributes from a simple Map
- OTelSemanticExtension on OTelSemantic
- Extension on OTelSemantic to provide utility methods.
Constants
- defaultTimeProvider → const TimeProvider
-
Platform default TimeProvider for native targets (Dart-VM, AOT,
Flutter mobile/desktop): SystemTimeProvider backed by
DateTime.now. Selected at compile time via the conditional export indefault_time_provider.dart.
Functions
-
otelApiFactoryFactoryFunction(
{required String apiEndpoint, required String apiServiceName, required String apiServiceVersion}) → OTelFactory - Factory function that creates an instance of OTelAPIFactory.
Typedefs
- LogFunction = void Function(String)
- Function type for logging operations
-
ObservableCallback<
T extends num> = void Function(APIObservableResult< T> result) - A callback function for observable instruments.
- OTelFactoryCreationFunction = OTelFactory Function({required String apiEndpoint, required String apiServiceName, required String apiServiceVersion})
- A function that creates the OTel Factory, used bu initialize methods