copyWithAttributes method
Creates a new Attributes instance by combining with another Attributes instance. Attributes from the other instance will overwrite attributes with the same keys in this instance.
@param other The Attributes instance to combine with @return A new Attributes instance with the combined attributes
Implementation
Attributes copyWithAttributes(Attributes other) {
return copyWith(other.toList());
}