of static method
Creates an Attributes instance from a map of key-value pairs. Uses the appropriate factory method (OTelFactory or OTelAPIFactory) based on initialization state.
@param map The map of key-value pairs to convert to attributes @return A new Attributes instance containing the converted attributes
Implementation
static Attributes of(Map<String, Object> map) {
return OTelFactory.getOrCreateDefault().attributesFromMap(map);
}