K8sPersistentvolumeStatusPhase enum
Values for k8s.persistentvolume.status.phase.
Stability: development
- Inheritance
- Implemented types
- Available extensions
Values
- available → const K8sPersistentvolumeStatusPhase
-
The volume is available and not yet bound to a claim.
Stability: development
const K8sPersistentvolumeStatusPhase('Available') - bound → const K8sPersistentvolumeStatusPhase
-
The volume is bound to a claim.
Stability: development
const K8sPersistentvolumeStatusPhase('Bound') - failed → const K8sPersistentvolumeStatusPhase
-
The volume has failed its automatic reclamation.
Stability: development
const K8sPersistentvolumeStatusPhase('Failed') - pending → const K8sPersistentvolumeStatusPhase
-
The volume is being provisioned.
Stability: development
const K8sPersistentvolumeStatusPhase('Pending') - released → const K8sPersistentvolumeStatusPhase
-
The claim has been deleted but the volume is not yet available.
Stability: development
const K8sPersistentvolumeStatusPhase('Released')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The on-wire attribute value string.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
K8sPersistentvolumeStatusPhase> - A constant List of the values in this enum, in order of their declaration.