Rpc enum
rpc.* attribute keys from the OpenTelemetry
semantic-conventions attribute registry.
- Inheritance
- Implemented types
- Available extensions
Values
- rpcConnectRpcErrorCode → const Rpc
-
Deprecated, use
rpc.response.status_codeattribute instead.Stability: development
const Rpc('rpc.connect_rpc.error_code') - rpcConnectRpcRequestMetadata → const Rpc
-
Deprecated, use
rpc.request.metadatainstead.Examples:
["1.2.3.4", "1.2.3.5"]Stability: development
const Rpc('rpc.connect_rpc.request.metadata') - rpcConnectRpcResponseMetadata → const Rpc
-
Deprecated, use
rpc.response.metadatainstead.Examples:
["attribute_value"]Stability: development
const Rpc('rpc.connect_rpc.response.metadata') - rpcGrpcRequestMetadata → const Rpc
-
Deprecated, use
rpc.request.metadatainstead.Examples:
["1.2.3.4", "1.2.3.5"]Stability: development
const Rpc('rpc.grpc.request.metadata') - rpcGrpcResponseMetadata → const Rpc
-
Deprecated, use
rpc.response.metadatainstead.Examples:
["attribute_value"]Stability: development
const Rpc('rpc.grpc.response.metadata') - rpcGrpcStatusCode → const Rpc
-
Deprecated, use string representation on the
rpc.response.status_codeattribute instead.Stability: development
const Rpc('rpc.grpc.status_code') - rpcJsonrpcErrorCode → const Rpc
-
Deprecated, use string representation on the
rpc.response.status_codeattribute instead.Examples:
-32700, 100Stability: development
const Rpc('rpc.jsonrpc.error_code') - rpcJsonrpcErrorMessage → const Rpc
-
Deprecated, use the span status description when reporting JSON-RPC spans.
Examples:
Parse error, User already existsStability: development
const Rpc('rpc.jsonrpc.error_message') - rpcJsonrpcRequestId → const Rpc
-
Deprecated, use
jsonrpc.request.idinstead.Examples:
10, request-7,Stability: development
const Rpc('rpc.jsonrpc.request_id') - rpcJsonrpcVersion → const Rpc
-
Deprecated, use
jsonrpc.protocol.versioninstead.Examples:
2.0, 1.0Stability: development
const Rpc('rpc.jsonrpc.version') - rpcMessageCompressedSize → const Rpc
-
Compressed size of the message in bytes.
Stability: development
const Rpc('rpc.message.compressed_size') - rpcMessageId → const Rpc
-
MUST be calculated as two different counters starting from
1one for sent messages and one for received message.Stability: development
const Rpc('rpc.message.id') - rpcMessageType → const Rpc
-
Whether this is a received or sent message.
Stability: development
const Rpc('rpc.message.type') - rpcMessageUncompressedSize → const Rpc
-
Uncompressed size of the message in bytes.
Stability: development
const Rpc('rpc.message.uncompressed_size') - rpcMethod → const Rpc
-
The fully-qualified logical name of the method from the RPC interface perspective.
Examples:
com.example.ExampleService/exampleMethod, EchoService/Echo, _OTHERStability: release_candidate
const Rpc('rpc.method') - rpcMethodOriginal → const Rpc
-
The original name of the method used by the client.
Examples:
com.myservice.EchoService/catchAll, com.myservice.EchoService/unknownMethod, InvalidMethodStability: release_candidate
const Rpc('rpc.method_original') - rpcRequestMetadata → const Rpc
-
RPC request metadata,
<key>being the normalized RPC metadata key (lowercase), the value being the metadata values.Examples:
["1.2.3.4", "1.2.3.5"]Stability: development
const Rpc('rpc.request.metadata') - rpcResponseMetadata → const Rpc
-
RPC response metadata,
<key>being the normalized RPC metadata key (lowercase), the value being the metadata values.Examples:
["attribute_value"]Stability: development
const Rpc('rpc.response.metadata') - rpcResponseStatusCode → const Rpc
-
Status code of the RPC returned by the RPC server or generated by the client
Examples:
OK, DEADLINE_EXCEEDED, -32602Stability: release_candidate
const Rpc('rpc.response.status_code') - rpcService → const Rpc
-
Deprecated, use fully-qualified
rpc.methodinstead.Examples:
myservice.EchoServiceStability: development
const Rpc('rpc.service') - rpcSystem → const Rpc
-
Deprecated, use
rpc.system.nameattribute instead.Stability: development
const Rpc('rpc.system') - rpcSystemName → const Rpc
-
The Remote Procedure Call (RPC) system.
Stability: release_candidate
const Rpc('rpc.system.name')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- key → String
-
The attribute key string as defined in the OpenTelemetry specification.
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMapEntry(
Object value) → MapEntry< String, Object> -
Available on OTelSemantic, provided by the OTelSemanticExtension extension
Converts this semantic attribute and its value to aMapEntry. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited