SystemMemoryState enum
Values for system.memory.state.
Stability: development
- Inheritance
- Implemented types
- Available extensions
Values
- used → const SystemMemoryState
-
Actual used virtual memory in bytes.
Stability: development
const SystemMemoryState('used') - free → const SystemMemoryState
-
Stability: development
const SystemMemoryState('free') -
Stability: development
const SystemMemoryState('shared') - buffers → const SystemMemoryState
-
Stability: development
const SystemMemoryState('buffers') - cached → const SystemMemoryState
-
Stability: development
const SystemMemoryState('cached')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The on-wire attribute value string.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SystemMemoryState> - A constant List of the values in this enum, in order of their declaration.