SystemMetric enum
system.* metric instruments from the OpenTelemetry
semantic conventions.
- Inheritance
- Implemented types
- Available extensions
Values
- systemCpuFrequency → const SystemMetric
-
Operating frequency of the logical CPU in Hertz.
Stability: development
const SystemMetric('system.cpu.frequency', SemanticInstrument.gauge, 'Hz') - systemCpuLogicalCount → const SystemMetric
-
Reports the number of logical (virtual) processor cores created by the operating system to manage multitasking.
Stability: development
const SystemMetric('system.cpu.logical.count', SemanticInstrument.upDownCounter, '{cpu}') - systemCpuPhysicalCount → const SystemMetric
-
Reports the number of actual physical processor cores on the hardware.
Stability: development
const SystemMetric('system.cpu.physical.count', SemanticInstrument.upDownCounter, '{cpu}') - systemCpuTime → const SystemMetric
-
Seconds each logical CPU spent on each mode.
Stability: development
const SystemMetric('system.cpu.time', SemanticInstrument.counter, 's') - systemCpuUtilization → const SystemMetric
-
For each logical CPU, the utilization is calculated as the change in cumulative CPU time (cpu.time) over a measurement interval, divided by the elapsed time.
Stability: development
const SystemMetric('system.cpu.utilization', SemanticInstrument.gauge, '1') - systemDiskIo → const SystemMetric
-
Disk bytes transferred.
Stability: development
const SystemMetric('system.disk.io', SemanticInstrument.counter, 'By') - systemDiskIoTime → const SystemMetric
-
Time disk spent activated.
Stability: development
const SystemMetric('system.disk.io_time', SemanticInstrument.counter, 's') - systemDiskLimit → const SystemMetric
-
The total storage capacity of the disk.
Stability: development
const SystemMetric('system.disk.limit', SemanticInstrument.upDownCounter, 'By') - systemDiskMerged → const SystemMetric
-
The number of disk reads/writes merged into single physical disk access operations.
Stability: development
const SystemMetric('system.disk.merged', SemanticInstrument.counter, '{operation}') - systemDiskOperationTime → const SystemMetric
-
Sum of the time each operation took to complete.
Stability: development
const SystemMetric('system.disk.operation_time', SemanticInstrument.counter, 's') - systemDiskOperations → const SystemMetric
-
Disk operations count.
Stability: development
const SystemMetric('system.disk.operations', SemanticInstrument.counter, '{operation}') - systemFilesystemLimit → const SystemMetric
-
The total storage capacity of the filesystem.
Stability: development
const SystemMetric('system.filesystem.limit', SemanticInstrument.upDownCounter, 'By') - systemFilesystemLockCount → const SystemMetric
-
Filesystem lock counts.
Stability: development
const SystemMetric('system.filesystem.lock.count', SemanticInstrument.upDownCounter, '{lock}') - systemFilesystemUsage → const SystemMetric
-
Reports a filesystem's space usage across different states.
Stability: development
const SystemMetric('system.filesystem.usage', SemanticInstrument.upDownCounter, 'By') - systemFilesystemUtilization → const SystemMetric
-
Fraction of filesystem bytes used.
Stability: development
const SystemMetric('system.filesystem.utilization', SemanticInstrument.gauge, '1') - systemLinuxMemoryAvailable → const SystemMetric
-
The number of packets transferred.
Stability: development
const SystemMetric('system.linux.memory.available', SemanticInstrument.counter, '{packet}') - systemLinuxMemorySlabUsage → const SystemMetric
-
The number of packets transferred.
Stability: development
const SystemMetric('system.linux.memory.slab.usage', SemanticInstrument.counter, '{packet}') - systemMemoryLimit → const SystemMetric
-
Total virtual memory available in the system.
Stability: development
const SystemMetric('system.memory.limit', SemanticInstrument.upDownCounter, 'By') - systemMemoryLinuxAvailable → const SystemMetric
-
An estimate of how much memory is available for starting new applications, without causing swapping.
Stability: development
const SystemMetric('system.memory.linux.available', SemanticInstrument.upDownCounter, 'By') - systemMemoryLinuxHugepagesLimit → const SystemMetric
-
Total number of hugepages available.
Stability: development
const SystemMetric('system.memory.linux.hugepages.limit', SemanticInstrument.upDownCounter, '{page}') - systemMemoryLinuxHugepagesPageSize → const SystemMetric
-
System hugepage size in bytes.
Stability: development
const SystemMetric('system.memory.linux.hugepages.page_size', SemanticInstrument.upDownCounter, 'By') - systemMemoryLinuxHugepagesReserved → const SystemMetric
-
Number of reserved hugepages.
Stability: development
const SystemMetric('system.memory.linux.hugepages.reserved', SemanticInstrument.upDownCounter, '{page}') - systemMemoryLinuxHugepagesSurplus → const SystemMetric
-
Number of surplus hugepages.
Stability: development
const SystemMetric('system.memory.linux.hugepages.surplus', SemanticInstrument.upDownCounter, '{page}') - systemMemoryLinuxHugepagesUsage → const SystemMetric
-
Number of hugepages in use by state.
Stability: development
const SystemMetric('system.memory.linux.hugepages.usage', SemanticInstrument.upDownCounter, '{page}') - systemMemoryLinuxHugepagesUtilization → const SystemMetric
-
Percentage of hugepages in use by state.
Stability: development
const SystemMetric('system.memory.linux.hugepages.utilization', SemanticInstrument.gauge, '1') -
Shared memory used (mostly by tmpfs).
Stability: development
const SystemMetric('system.memory.linux.shared', SemanticInstrument.upDownCounter, 'By') - systemMemoryLinuxSlabUsage → const SystemMetric
-
Reports the memory used by the Linux kernel for managing caches of frequently used objects.
Stability: development
const SystemMetric('system.memory.linux.slab.usage', SemanticInstrument.upDownCounter, 'By') -
Deprecated, use
system.memory.linux.sharedinstead.Stability: development
const SystemMetric('system.memory.shared', SemanticInstrument.upDownCounter, 'By') - systemMemoryUsage → const SystemMetric
-
Reports memory in use by state.
Stability: development
const SystemMetric('system.memory.usage', SemanticInstrument.upDownCounter, 'By') - systemMemoryUtilization → const SystemMetric
-
Percentage of memory bytes in use.
Stability: development
const SystemMetric('system.memory.utilization', SemanticInstrument.gauge, '1') - systemNetworkConnectionCount → const SystemMetric
-
The number of connections.
Stability: development
const SystemMetric('system.network.connection.count', SemanticInstrument.upDownCounter, '{connection}') - systemNetworkConnections → const SystemMetric
-
Deprecated, use
system.network.connection.countinstead.Stability: development
const SystemMetric('system.network.connections', SemanticInstrument.upDownCounter, '{connection}') - systemNetworkDropped → const SystemMetric
-
Count of packets that are dropped or discarded even though there was no error.
Stability: development
const SystemMetric('system.network.dropped', SemanticInstrument.counter, '{packet}') - systemNetworkErrors → const SystemMetric
-
Count of network errors detected.
Stability: development
const SystemMetric('system.network.errors', SemanticInstrument.counter, '{error}') - systemNetworkIo → const SystemMetric
-
The number of bytes transmitted and received.
Stability: development
const SystemMetric('system.network.io', SemanticInstrument.counter, 'By') - systemNetworkPacketCount → const SystemMetric
-
The number of packets transferred.
Stability: development
const SystemMetric('system.network.packet.count', SemanticInstrument.counter, '{packet}') - systemNetworkPacketDropped → const SystemMetric
-
Count of packets that are dropped or discarded even though there was no error.
Stability: development
const SystemMetric('system.network.packet.dropped', SemanticInstrument.counter, '{packet}') - systemNetworkPackets → const SystemMetric
-
The number of packets transferred.
Stability: development
const SystemMetric('system.network.packets', SemanticInstrument.counter, '{packet}') - systemPagingFaults → const SystemMetric
-
The number of page faults.
Stability: development
const SystemMetric('system.paging.faults', SemanticInstrument.counter, '{fault}') - systemPagingOperations → const SystemMetric
-
The number of paging operations.
Stability: development
const SystemMetric('system.paging.operations', SemanticInstrument.counter, '{operation}') - systemPagingUsage → const SystemMetric
-
Unix swap or windows pagefile usage.
Stability: development
const SystemMetric('system.paging.usage', SemanticInstrument.upDownCounter, 'By') - systemPagingUtilization → const SystemMetric
-
Swap (unix) or pagefile (windows) utilization.
Stability: development
const SystemMetric('system.paging.utilization', SemanticInstrument.gauge, '1') - systemProcessCount → const SystemMetric
-
Total number of processes in each state.
Stability: development
const SystemMetric('system.process.count', SemanticInstrument.upDownCounter, '{process}') - systemProcessCreated → const SystemMetric
-
Total number of processes created over uptime of the host.
Stability: development
const SystemMetric('system.process.created', SemanticInstrument.counter, '{process}') - systemUptime → const SystemMetric
-
The time the system has been running.
Stability: development
const SystemMetric('system.uptime', SemanticInstrument.gauge, 's')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- instrument → SemanticInstrument
-
The OTel instrument kind the spec assigns to this metric.
final
- name → String
-
The on-wire metric name (e.g.
http.server.request.duration).final - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unit → String
-
OTel unit string (UCUM-style:
sfor seconds,Byfor bytes,{request}for a counted entity,1for dimensionless).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SystemMetric> - A constant List of the values in this enum, in order of their declaration.